---
title: <span class="badge object-type-scalar"></span> BytesSI
---
# <span class="badge object-type-scalar"></span> BytesSI

Data: bytes(SI)

## Definition

```python
# Data: bytes(SI)
BytesSI: typing.Literal["decbytes"] = "decbytes"
```
